@@ -201,8 +201,10 @@ pub enum DataType {
     GpsRtkExtendedRawMeasurementData    = 0xDB, // RTK RAW 데이터 전송
 
     // Linux Server Device
-    ExternalCameraState     = 0xE0,     // 카메라 동작 상태
-    ExternalCameraCommand   = 0xE1,     // 카메라 제어 명령
+    ExternalSystemState     = 0xE0,     // 0xE0
+    ExternalSystemCommand   = 0xE1,     // 0xE1
+    ExternalCameraState     = 0xE2,     // 카메라 동작 상태
+    ExternalCameraCommand   = 0xE3,     // 카메라 제어 명령
     
 }
 
@@ -320,8 +322,10 @@ pub enum Data {
     NavigationSatellite (navigation::Satellite),              // 0xD5
     NavigationLocationAdjust (navigation::LocationAdjust),    // 0xD6
     
-    ExternalCameraState (external::camera::State),      // 0xE0
-    ExternalCameraCommand (external::camera::Command),  // 0xE1
+    ExternalSystemState (external::system::State),      // 0xE0
+    ExternalSystemCommand (external::system::Command),  // 0xE1
+    ExternalCameraState (external::camera::State),      // 0xE2
+    ExternalCameraCommand (external::camera::Command),  // 0xE3
 }
 
 
